SELECT
    `db`.`Mitarbeiter` AS `Mitarbeiter`,
    `db`.`Jahr` AS `Jahr`,
    `db`.`Zeit` AS `Zeit`,
    `db`.`belegnr` AS `belegnr`,
    `db`.`status` AS `status`,
    `db`.`name` AS `name`,
    `db`.`artnr` AS `Artikelnummer`,
    `db`.`Bezeichnung` AS `Bezeichnung`,
    `db`.`Menge` AS `Menge`,
    `db`.`Preis` AS `Preis`,
    `db`.`Menge` * `db`.`Preis` AS `Umsatz`,
    `db`.`EK` AS `EK`,
    `db`.`ManEK` AS `ManEK`
FROM
    (
    SELECT
        `rechnungen`.`Mitarbeiter` AS `Mitarbeiter`,
        `rechnungen`.`Jahr` AS `Jahr`,
        `rechnungen`.`Zeit` AS `Zeit`,
        `rechnungen`.`belegnr` AS `belegnr`,
        `rechnungen`.`status` AS `status`,
        `rechnungen`.`name` AS `name`,
        `rechnungen`.`artnr` AS `artnr`,
        `rechnungen`.`Bezeichnung` AS `Bezeichnung`,
        `rechnungen`.`Menge` AS `Menge`,
        `rechnungen`.`Preis` AS `Preis`,
        `rechnungen`.`EK` AS `EK`,
        `rechnungen`.`ManEK` AS `ManEK`
    FROM
        (
        SELECT
            `adresse`.`vertrieb` AS `Mitarbeiter`,
            DATE_FORMAT(`rechnung`.`datum`, '%Y') AS `Jahr`,
            DATE_FORMAT(`rechnung`.`datum`, '%m') AS `Zeit`,
            `rechnung`.`belegnr` AS `belegnr`,
            `rechnung`.`status` AS `status`,
            `adresse`.`name` AS `name`,
            `artikel`.`nummer` AS `artnr`,
            SUBSTR(`artikel`.`name_de`, 1, 40) AS `Bezeichnung`,
            ROUND(
                SUM(
                    `rechnung_position`.`menge`
                ),
                0
            ) AS `Menge`,
            ROUND(
                SUM(
                    `rechnung_position`.`preis`
                ),
                2
            ) AS `Preis`,
            CASE WHEN `artikel`.`verwendeberechneterek` = 1 THEN ROUND(
                `artikel`.`berechneterek`,
                2
            ) ELSE ROUND(
                (
                SELECT
                    MIN(`einkaufspreise`.`preis`)
                FROM
                    `einkaufspreise`
                WHERE
                    `einkaufspreise`.`artikel` = `artikel`.`id` AND `einkaufspreise`.`gueltig_bis` = '0000-00-00'
            ),
            2
            )
    END AS `EK`,
    CASE WHEN `artikel`.`verwendeberechneterek` = 1 THEN 'Ja' ELSE ''
END AS `ManEK`
FROM
    (
        (
            (
                `rechnung`
            JOIN `rechnung_position` ON
                (
                    `rechnung_position`.`rechnung` = `rechnung`.`id`
                )
            )
        JOIN `artikel` ON
            (
                `rechnung_position`.`artikel` = `artikel`.`id`
            )
        )
    JOIN `adresse` ON
        (
            `rechnung`.`adresse` = `adresse`.`id`
        )
    )
WHERE
    `rechnung`.`status` = 'versendet' OR `rechnung`.`status` = 'freigegeben' OR `rechnung`.`status` = 'storniert'
GROUP BY
    DATE_FORMAT(`rechnung`.`datum`, '%Y'),
    `adresse`.`vertrieb`,
    DATE_FORMAT(`rechnung`.`datum`, '%m'),
    `rechnung`.`belegnr`,
    `rechnung`.`status`,
    `artikel`.`nummer`,
    `adresse`.`name`,
    `artikel`.`name_de`,
    `artikel`.`id`
ORDER BY
    DATE_FORMAT(`rechnung`.`datum`, '%Y'),
    `adresse`.`vertrieb`,
    DATE_FORMAT(`rechnung`.`datum`, '%m'),
    `rechnung`.`belegnr`
) `rechnungen`
UNION
    (
    SELECT
        `adresse`.`vertrieb` AS `Mitarbeiter`,
        DATE_FORMAT(`gutschrift`.`datum`, '%Y') AS `Jahr`,
        DATE_FORMAT(`gutschrift`.`datum`, '%m') AS `Zeit`,
        `gutschrift`.`belegnr` AS `belegnr`,
        `gutschrift`.`status` AS `status`,
        `adresse`.`name` AS `name`,
        `artikel`.`nummer` AS `artnr`,
        SUBSTR(`artikel`.`name_de`, 1, 40) AS `Bezeichnung`,
        - ROUND(
            SUM(
                `gutschrift_position`.`menge`
            ),
            0
        ) AS `Menge`,
        ROUND(
            SUM(
                `gutschrift_position`.`preis`
            ),
            2
        ) AS `Preis`,
        CASE WHEN `artikel`.`verwendeberechneterek` = 1 THEN ROUND(
            `artikel`.`berechneterek`,
            2
        ) ELSE ROUND(
            (
            SELECT
                MIN(`einkaufspreise`.`preis`)
            FROM
                `einkaufspreise`
            WHERE
                `einkaufspreise`.`artikel` = `artikel`.`id` AND `einkaufspreise`.`gueltig_bis` = '0000-00-00'
        ),
        2
        )
END AS `EK`,
CASE WHEN `artikel`.`verwendeberechneterek` = 1 THEN 'Ja' ELSE ''
END AS `ManEK`
FROM
    (
        (
            (
                `gutschrift`
            JOIN `gutschrift_position` ON
                (
                    `gutschrift_position`.`gutschrift` = `gutschrift`.`id`
                )
            )
        JOIN `artikel` ON
            (
                `gutschrift_position`.`artikel` = `artikel`.`id`
            )
        )
    JOIN `adresse` ON
        (
            `gutschrift`.`adresse` = `adresse`.`id`
        )
    )
WHERE
    `gutschrift`.`status` = 'versendet' OR `gutschrift`.`status` = 'freigegeben' OR `gutschrift`.`status` = 'storniert'
GROUP BY
    DATE_FORMAT(`gutschrift`.`datum`, '%Y'),
    `adresse`.`vertrieb`,
    DATE_FORMAT(`gutschrift`.`datum`, '%m'),
    `gutschrift`.`belegnr`,
    `gutschrift`.`status`,
    `adresse`.`name`,
    `artikel`.`nummer`,
    `artikel`.`name_de`,
    `artikel`.`id`
)
) `db`
